<?php

namespace Drupal\students;

use Drupal\Core\Controller\ControllerBase;

/**
 * Class StudentsStorage.
 *
 * @package Drupal\students
 */
class StudentsStorage extends ControllerBase {

  /**
   * Method getAll().
   *
   * @return mixed
   *   DB query.
   */
  public static function getAll() {
    $result = db_query('SELECT * FROM {students}')->fetchAllAssoc('id');
    return $result;
  }

  /**
   * Get if $id exists.
   *
   * @param string $id
   *   Id of the record.
   *
   * @return bool
   *   Execute get($id) method and return bool.
   */
  public static function exists($id) {
    return (bool) self::get($id);
  }

  /**
   * Getter of DB Students data.
   *
   * @param string $id
   *   Id of the record.
   *
   * @return bool|array
   *   DB query.
   */
  public static function get($id) {
    $result = db_query('SELECT * FROM {students} WHERE id = :id', [':id' => $id])
      ->fetchAllAssoc('id');
    if ($result) {
      return $result[$id];
    }
    else {
      return FALSE;
    }
  }

  /**
   * Add method.
   *
   * @param string $name
   *   Student's name.
   * @param string $gender
   *   Student's gender.
   * @param string $faculty_number
   *   Student's faculty number.
   *
   * @throws \Exception
   *   DB insert query.
   */
  public static function add($name, $gender, $faculty_number) {
    db_insert('students')->fields([
      'name' => $name,
      'gender' => $gender,
      'faculty_number' => $faculty_number,
    ])
      ->execute();
  }

  /**
   * Edit method.
   *
   * @param string $id
   *   Student's id.
   * @param string $name
   *   Student's name.
   * @param string $gender
   *   Student's gender.
   * @param string $faculty_number
   *   Student's faculty number.
   */
  public static function edit($id, $name, $gender, $faculty_number) {
    db_update('students')->fields([
      'name' => $name,
      'gender' => $gender,
      'faculty_number' => $faculty_number,
    ])
      ->condition('id', $id)
      ->execute();
  }

  /**
   * Delete method.
   *
   * @param string $id
   *   DB delete query.
   */
  public static function delete($id) {
    db_delete('students')->condition('id', $id)->execute();
  }

}
